@@ -19,9 +19,11 @@
  */
 
 #include <QApplication>
-#include <QSqlDatabase>
-#include <QMessageBox>
+#include <QDebug>
 #include <QFile>
+#include <QMessageBox>
+#include <QSqlDatabase>
+#include <QSqlError>
 #include <QTextStream>
 #include <xsqlquery.h>
 
@@ -38,13 +40,65 @@
 
 typedef QPair<bool, QVariant> ParamPair;
 
+// TODO: move db-related usage & args processing and db.open() to common dir?
+QStringList usage()
+{
+  QStringList m;
+  m << QObject::tr("rptrender [options]")
+    << ""
+    << QObject::tr("-help        display usage information")
+    << QObject::tr("--help       display usage information")
+    << ""
+    << QObject::tr("-databaseURL=drv://host:port/dbname")
+    << QObject::tr("                log in to database dbname on the given host and port")
+    << QObject::tr("                using the Qt database driver drv")
+    << QObject::tr("-d dbname       log in to database dbname")
+    << QObject::tr("-h addr         look for the database server on host addr")
+    << QObject::tr("-p #            look for the database server on port #")
+    << QObject::tr("-P drv          use the Qt database driver drv")
+    << QObject::tr("-U x            log in as user x")
+    << QObject::tr("-username=x     log in as user x")
+    << QObject::tr("-passwd=w       log in with password w")
+    << QObject::tr("-noauth         (deprecated & ignored)")
+    << ""
+    << QObject::tr("-numCopies=#    produce # copies of the report")
+    << QObject::tr("-printpreview   preview the report with an option to print")
+    << QObject::tr("-print          print the report, prompting for the printer to use")
+    << QObject::tr("-autoprint      print to the default printer")
+    << QObject::tr("-printerName=P  send output to the system printer P")
+    << QObject::tr("-pdf            generate PDF output")
+    << QObject::tr("-outpdf=FILE    send PDF output to FILE")
+    << ""
+    << QObject::tr("-loadfromdb=RPT load the named RPT from the database")
+    << ""
+    << QObject::tr("-param='[+-]name[:type][=value]'")
+    << QObject::tr("         define/set a MetaSQL parameter with optional value and type")
+    << QObject::tr("         '-' means the parameter is defined but inactive")
+    << QObject::tr("         '+' means the parameter is active (default)")
+    << QObject::tr("-e       use the value 'Missing' for undefined parameters")
+    << ""
+    << QObject::tr("-close   quit when finished generating the report")
+    << QObject::tr("-fromStdin=codec")
+    << QObject::tr("         read and parse arguments from the standard input instead of")
+    << QObject::tr("         the command line, using the named codec, one argument per line.")
+    << QObject::tr("         Stop reading when the line starts with -launch")
+    << ""
+    ;
+  return m;
+}
+
 int main(int argc, char *argv[])
 {
   QMap<QString,ParamPair> paramList;
-  QString username  = "";
+  QString username = "";
   QString filename;
   QString printerName;
-  bool    haveUsername    = false;
+  QString hostName;
+  QString dbName;
+  QString port;
+  QString protocol("QPSQL");
+  QSqlDatabase db;
+
   bool    haveDatabaseURL = false;
   bool    loggedIn        = false;
   bool    print           = false;
@@ -52,11 +106,8 @@ int main(int argc, char *argv[])
   bool    close           = false;
   bool    autoPrint       = false;                      //AUTOPRINT
   int     numCopies       = 1;
-  // BVI::Sednacom
-  // new options
   bool    pdfOutput = false;
   QString pdfFileName;
-  // BVI::Sednacom
 
   QString databaseURL = "";
   QString loadFromDB = "";
@@ -72,9 +123,7 @@ int main(int argc, char *argv[])
 
   if (argc > 1)
   {
-    haveUsername        = false;
-    bool    havePasswd          = false;
-    QString passwd              = "";
+    QString passwd;
 
     QStringList arguments;
     QString firstArgument = QString( argv[ 1 ] );
@@ -83,7 +132,7 @@ int main(int argc, char *argv[])
       QFile file;
       file.open(stdin, QIODevice::ReadOnly);
       QTextStream in(&file);
-      in.setCodec( firstArgument.right( firstArgument.length() - 11 ).toLatin1() ); 
+      in.setCodec( firstArgument.right( firstArgument.length() - 11 ).toLatin1() );
       QString arg;
       while( arg.compare("-launch") !=0 ){
         arg = in.readLine();
@@ -100,24 +149,52 @@ int main(int argc, char *argv[])
     for ( QStringList::Iterator it = arguments.begin(); it != arguments.end(); ++it ) {
       QString argument( *it );
 
-      if (argument.startsWith("-databaseURL=", Qt::CaseInsensitive)) {
+      if (argument.startsWith("-help") || argument.startsWith("--help"))
+      {
+        QTextStream(stdout) << usage().join("\n");
+        QApplication::exit(0);
+        return 0; // QApplication::exit() quits the event loop, not main()?!
+      }
+      else if (argument.startsWith("-databaseURL=", Qt::CaseInsensitive)) {
         haveDatabaseURL = true;
-        databaseURL    = argument.right(argument.length() - 13);
+        databaseURL     = argument.right(argument.length() - 13);
+      }
+      else if (argument == "-d")
+      {
+        it++;
+        dbName = QString(*it);
+      }
+      else if (argument == "-h")
+      {
+        it++;
+        hostName = QString(*it);
+      }
+      else if (argument == "-p")
+      {
+        it++;
+        port = QString(*it);
+      }
+      else if (argument == "-P")
+      {
+        it++;
+        protocol = normalizeProtocol(QString(*it));
+      }
+      else if (argument == "-U")
+      {
+        it++;
+        username = QString(*it);
       }
       else if (argument.startsWith("-username=", Qt::CaseInsensitive))
       {
-        haveUsername = true;
-        username     = argument.right(argument.length() - 10);
+        username = argument.right(argument.length() - 10);
       }
       else if (argument.startsWith("-passwd=", Qt::CaseInsensitive))
       {
-        havePasswd = true;
-        passwd     = argument.right(argument.length() - 8);
+        passwd = argument.right(argument.length() - 8);
       }
       else if (argument.toLower() == "-noauth")
       {
-        haveUsername = true;
-        havePasswd   = true;
+        qDebug() << QObject::tr("%1 is deprecated").arg(argument);
       }
       else if (argument.startsWith("-numCopies=", Qt::CaseInsensitive)){
         numCopies = argument.right( argument.length() - 11).toInt();
@@ -164,54 +241,61 @@ int main(int argc, char *argv[])
           var = XVariant::decode(type, value);
         paramList[name] = ParamPair(active, var);
       }
-      // BVI::Sednacom
-      // manage new arguments for CLI
       else if (argument.startsWith("-pdf", Qt::CaseInsensitive)) {
         pdfOutput = true ;
       }
       else if (argument.startsWith("-outpdf=", Qt::CaseInsensitive)) {
         pdfFileName = argument.right(argument.length() - 8 ) ;
       }
-      // BVI::Sednacom
       else if (argument.startsWith("-loadfromdb=", Qt::CaseInsensitive))
         loadFromDB = argument.right(argument.length() - 12);
       else if (argument.toLower() == "-e")
         XSqlQuery::setNameErrorValue("Missing");
-      else if (argument.toLower() == "-autoprint"){            //AUTOPRINT
-          print=true;                                          //Auto print means they want to print.
-          autoPrint=true;
+      else if (argument.toLower() == "-autoprint")
+      {
+        print=true;
+        autoPrint=true;
       }
-      else if(!argument.startsWith("-"))
+      else if (argument == "-launch")
+        ; // ignore
+      else if (argument.startsWith("-"))
+        qDebug() << "Ignoring unknown argument" << argument;
+      else
         filename = argument;
     }
 
-    if ( (haveDatabaseURL) && (haveUsername) && (havePasswd) )
+    if (haveDatabaseURL)
     {
-      QSqlDatabase db;
-      QString      protocol;
-      QString      hostName;
-      QString      dbName;
-      QString      port;
-
       db = databaseFromURL( databaseURL );
-      if (!db.isValid())
-      {
-        QMessageBox::critical(0, QObject::tr("Can not load database driver"), QObject::tr("Unable to load the database driver. Please contact your systems administrator."));
-        QApplication::exit(-1);
-      }
-
-      db.setUserName(username);
-      db.setPassword(passwd);
-
-      if (!db.open())
-      {
-        QMessageBox::critical(0, QObject::tr("Unable to connect to database"), QObject::tr("Unable to connect to the database with the given information."));
-        QApplication::exit(-1);
-      }
-      else
-        loggedIn = true;
+    }
+    else
+    {
+      db = QSqlDatabase::addDatabase(protocol);
+      db.setHostName(hostName);
+      if (! port.isEmpty())
+        db.setPort(port.toInt());
+      if (! dbName.isEmpty())
+          db.setDatabaseName(dbName);
     }
 
+    db.setUserName(username);
+    if (! passwd.isNull())
+      db.setPassword(passwd);
+
+    loggedIn = db.open();
+
+    if (! loggedIn)
+    {
+      if (close)
+      {
+        QTextStream(stderr) << db.lastError().databaseText();
+        QApplication::exit(-1);
+        return -1;
+      }
+      else
+        QMessageBox::critical(0, QObject::tr("Unable to connect to database"),
+                              db.lastError().databaseText());
+    }
   }
 
   if(!loggedIn)
@@ -222,7 +306,7 @@ int main(int argc, char *argv[])
     params.append("version",   OpenRPT::version);
     params.append("build",     OpenRPT::build);
 
-    if (haveUsername)
+    if (! username.isEmpty())
       params.append("username", username);
 
     if (haveDatabaseURL)
@@ -336,7 +420,7 @@ int main(int argc, char *argv[])
   // BVI::Sednacom
   // generate the PDF
   if (pdfOutput)
-    mainwin.filePrintToPDF(pdfFileName);  
+    mainwin.filePrintToPDF(pdfFileName);
   // BVI::Sednacom
 
   if(close)
