@@ -1,6 +1,6 @@
 /*
  * OpenRPT report writer and rendering engine
- * Copyright (C) 2001-2012 by OpenMFG, LLC
+ * Copyright (C) 2001-2014 by OpenMFG, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -64,12 +64,6 @@ bool ORPrintRender::setupPrinter(ORODocument * pDocument, QPrinter * pPrinter)
   PageSizeInfo psi = PageSizeInfo::getByName(pDocument->pageOptions().getPageSize());
   if(psi.isNull())
   {
-    // TODO:
-    //psi = PageSizeInfo::findNearest((int)(pDocument->pageOptions().getCustomWidth() * 100), (int)(pDocument->pageOptions().getCustomHeight() * 100));
-    //if(psi.isNull())
-    //  pPrinter->setPageSize(QPrinter::Custom);
-    //else
-    //  pPrinter->setPageSize((QPrinter::PageSize)psi.qpValue());
     pPrinter->setPaperSize(QSizeF(pDocument->pageOptions().getCustomWidth(), pDocument->pageOptions().getCustomHeight()), QPrinter::Inch);
   }
   else 
@@ -77,7 +71,9 @@ bool ORPrintRender::setupPrinter(ORODocument * pDocument, QPrinter * pPrinter)
     #if defined(Q_WS_MAC) && (QT_VERSION < 0x040801) // QTBUG-20882
       pPrinter->setPageSize((QPrinter::PageSize)psi.qpValue());
     #else
-      pPrinter->setPaperSize(QSizeF(psi.width()/100,psi.height()/100), QPrinter::Inch);
+      if (pDocument->pageOptions().getPageSize() == "Custom")
+        pPrinter->setPaperSize(QSizeF(psi.width()  / 100.0,
+                                      psi.height() / 100.0), QPrinter::Inch);
     #endif
   }
 
@@ -207,21 +203,19 @@ void renderBackground(QImage & dest, const QImage & bgImage, const QRect & bgRec
 #include <math.h>
 #include <QFontDatabase>
 
-void renderWatermark(QImage & image, const QString & wmText, const QFont & wmFont, const unsigned int wmOpacity, double pA, double pB, double pC, double pD)
+// margin is in the same units as the image
+void renderWatermark(QImage & image, const QString & wmText, const QFont & wmFont, const unsigned int wmOpacity, double leftMargin, double rightMargin, double topMargin, double bottomMargin)
 {
   const double pi = 3.14159265358979323846;
 
-  double w = ((double)image.width() - pA);
-  double h = ((double)image.height() - pB);
+  double w = (double)image.width() - (leftMargin + rightMargin);
+  double h = (double)image.height() - (topMargin + bottomMargin);
   double theta = (pi/-2.0) + atan(w / h);
   double l = sqrt((w * w) + (h * h));
 
   const double sintheta = sin(theta);
   const double costheta = cos(theta);
 
-  double margin_width = pC;
-  double margin_height = pD;
-
   int offset = (int)(l * 0.05);
   int l2 = (int)(l * 0.9);
 
@@ -252,7 +246,7 @@ void renderWatermark(QImage & image, const QString & wmText, const QFont & wmFon
   QPainter pPainter;
   pPainter.begin(&wm);
   pPainter.setFont(fnt);
-  pPainter.translate(margin_width, margin_height);
+  pPainter.translate(leftMargin, topMargin);
   pPainter.rotate((theta/pi)*180);
   pPainter.drawText(x, y, l2, fh, Qt::AlignCenter, wmText);
   pPainter.end();
@@ -284,8 +278,8 @@ void ORPrintRender::renderPage(ORODocument * pDocument, int pageNb, QPainter *pa
     // Do some simple processing used by both Background and Watermark
     const int resolution = 100;
     bool doBgWm = false;
-    int printMarginWidth = margins.width();
-    int printMarginHeight = margins.height();
+    int printMarginWidth  = margins.width()  < 0 ? 0 : margins.width();
+    int printMarginHeight = margins.height() < 0 ? 0 : margins.height();
 
     QString pageSize = pDocument->pageOptions().getPageSize();
     int pageWidth = 0;
@@ -338,16 +332,20 @@ void ORPrintRender::renderPage(ORODocument * pDocument, int pageNb, QPainter *pa
     {
       doBgWm = true;
       renderWatermark(image, p->watermarkText(), p->watermarkFont(), p->watermarkOpacity(),
-        ((pDocument->pageOptions().getMarginLeft() + pDocument->pageOptions().getMarginRight()) * resolution),
-        ((pDocument->pageOptions().getMarginTop() + pDocument->pageOptions().getMarginBottom()) * resolution),
-        pDocument->pageOptions().getMarginLeft() * resolution, pDocument->pageOptions().getMarginTop() * resolution);
+                      pDocument->pageOptions().getMarginLeft()   * resolution,
+                      pDocument->pageOptions().getMarginRight()  * resolution,
+                      pDocument->pageOptions().getMarginTop()    * resolution,
+                      pDocument->pageOptions().getMarginBottom() * resolution);
     }
 
     if(doBgWm)
     {
-      QRectF target(-printMarginWidth, -printMarginHeight, (painter->viewport().width() + printMarginWidth + printMarginWidth), (painter->viewport().height() + printMarginHeight + printMarginHeight));
+      QRectF target(0, 0, pageWidth, pageHeight);
+      painter->save();
+      painter->scale(xDpi / resolution, yDpi / resolution);
       QRectF source(0, 0, image.width(), image.height());
       painter->drawImage(target, image, source);
+      painter->restore();
     }
   }
 
