@@ -1,6 +1,6 @@
 /*
  * OpenRPT report writer and rendering engine
- * Copyright (C) 2001-2012 by OpenMFG, LLC
+ * Copyright (C) 2001-2014 by OpenMFG, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@ public:
   QueryComboBox(QWidget *parent);
   ~QueryComboBox();
 
-  void init(QuerySourceList * qsl, const QString &query, bool paramAndContextQueries=TRUE);
+  void init(QuerySourceList * qsl, const QString &query, bool paramAndContextQueries=true);
   QString currentQuery();
 
 };
